@@ -35,6 +35,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 use overload (
 	'""'  =>   sub { stringify($_[0]) },
 	'0+'  =>   sub { intify($_[0]) },
+	'bool' =>  sub { $_[0] != 0 },
 
 	'<=>' =>   \&op_spaceship,
 	'=='  =>   \&op_eq,
@@ -61,7 +62,7 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '2.07';
+our $VERSION = '2.08';
 
 sub AUTOLOAD {
 	# This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -140,7 +141,7 @@ Math::GMP - High speed arbitrary size integer math
 =head1 SYNOPSIS
 
   use Math::GMP;
-  my $n = new Math::GMP 2;
+  my $n = Math::GMP->new('2');
 
   $n = $n ** (256*1024);
   $n = $n - 1;
@@ -192,9 +193,10 @@ be represented in the base specified by the second parameter.
 =head2 bfac
 
   $x = Math::GMP->new(5);
-  $x->bfac();      # 1*2*3*4*5 = 120
+  my $val = $x->bfac();      # 1*2*3*4*5 = 120
+  print $val;
 
-Calculates the factorial of $x and modifies $x to contain the result.
+Calculates the factorial of $x and returns the result.
 
 =head2 band
 
@@ -270,7 +272,7 @@ when $y is odd; when the value is not defined, this currently returns 0
 
 =head2 fibonacci
 
-  $x = Math::GMP->fibonacci(16);
+  $x = Math::GMP::fibonacci(16);
 
 Calculates the n'th number in the Fibonacci sequence.
 
@@ -297,6 +299,12 @@ numbers not being prefixed by a '+' sign.  This is intentional.
 There are also some things missing, and not everything might work as
 expected.
 
+=head1 VERSION CONTROL
+
+The version control repository of this module is a git repository hosted
+on GitHub at: L<https://github.com/turnstep/Math-GMP>. Pull requests are
+welcome.
+
 =head1 SEE ALSO
 
 Math::BigInt has a new interface to use a different library than the
